
# Slot: evidence

The set of evidence items that support the association.

URI: [gocam:association__evidence](https://w3id.org/gocam/association__evidence)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [EvidenceItem](EvidenceItem.md)

## Parents


## Children


## Used by

 * [Association](Association.md)
 * [BiologicalProcessAssociation](BiologicalProcessAssociation.md)
 * [CausalAssociation](CausalAssociation.md)
 * [CellTypeAssociation](CellTypeAssociation.md)
 * [CellularAnatomicalEntityAssociation](CellularAnatomicalEntityAssociation.md)
 * [EnabledByAssociation](EnabledByAssociation.md)
 * [EnabledByGeneProductAssociation](EnabledByGeneProductAssociation.md)
 * [EnabledByProteinComplexAssociation](EnabledByProteinComplexAssociation.md)
 * [GrossAnatomyAssociation](GrossAnatomyAssociation.md)
 * [MolecularFunctionAssociation](MolecularFunctionAssociation.md)
 * [MoleculeAssociation](MoleculeAssociation.md)
 * [TermAssociation](TermAssociation.md)
